
import numpy as np
import CupInitialPostion as cip
import plotly.graph_objs as go
from plotly.offline import plot
import math 
import pandas as pd

def calculateCupAnlges(unit_plane_normal, vector_to_project, angle_axis): # in current state this function is derived only for inclination in frontal plane and version in transverse plane, suitablity for other measurements
    # make sure vector is vector not a point in space + make sure vector is np.array
    # one gait cycle point only 
    # projections based on https://www.maplesoft.com/support/help/maple/view.aspx?path=MathApps%2FProjectionOfVectorOntoPlane
    
    pre_projected_vector = np.multiply(np.dot(vector_to_project, unit_plane_normal),  unit_plane_normal)
    projected_vector = vector_to_project - pre_projected_vector
    normal = 1 #np.linalg.norm(projected_vector)*np.linalg.norm(angle_axis)
    scalar_pv_axis = math.acos(np.dot(projected_vector, angle_axis)/normal) #pv - projected_vector, axis - axis to measure angle against
    angle_value = np.rad2deg((math.pi/2) - scalar_pv_axis)
    results = {'projected_vector' : projected_vector, 'angle_value' : angle_value}
    return results

def batchCupAngles(data_frame_file, return_file):

    # for every point extract x, y, z into np.array
    df_vector_data = pd.read_json(data_frame_file, orient='split')
    np_vector_data = df_vector_data.to_numpy()

    # define inclination and version axes
    inclination_axis = np.array([1., 0., 0. ]) 
    version_axis = np.array([0., 1., 0. ]) 

    # define inclination and version planes (frontal and transverse)

    inclination_plane = np.array([0., 1., 0]) 
    version_plane = np.array([0., 0., 1]) 
    # for every time-point run calculateCupAngles for inclination and version - record to pd.dataframe
    i = 0
    df_results = pd.DataFrame(columns = ['inclination' , 'version'])
    while i < len(np_vector_data):
        inclination_angle = calculateCupAnlges(inclination_plane, np_vector_data[i], inclination_axis)
        inclination_angle = inclination_angle['angle_value']
        version_angle = calculateCupAnlges(version_plane, np_vector_data[i], version_axis)
        version_angle = version_angle['angle_value']
        result = [inclination_angle, version_angle]
        df = pd.DataFrame([result],
                   columns = ['inclination' , 'version'])
        df_results = df_results.append(df, ignore_index=True)
        i += 1
    else: 
        print('done')

    # record final result to json and return pd.dataframe
    df_results.to_json(return_file, orient='split')
    return df_results

def visualisedynamicCup(input_data, save_file_name = 'test'):
    figure = go.Figure()
    df_vector_data = pd.read_json(input_data, orient='split') 
    figure.add_trace(go.Scatter( x = df_vector_data.loc[:, 'version'], y = df_vector_data.loc[:, 'inclination'], 
         marker = dict(
        color = '#FFBAD2',
        line = dict(width = 1)
    )))
    figure.update_layout(title = 'Dynamic Cup Angles Patient', xaxis = dict(
        title = 'Version'),
    yaxis = dict(
        title = 'Inclination'))
    plot(figure, filename= save_file_name +'angles.html', auto_open=True) #can change directrory if needed for now same directory as the script
    
    #x axis - version, y - axis inclination 

# def visualiseStationaryCup(): #original position
    #x axis - version, y - axis inclination 

if (__name__ == '__main__'):

    
    inclination_plane = np.array([0., 1., 0]) 
    version_plane = np.array([0., 0., 1]) 

    inclination_axis = np.array([1., 0., 0. ]) 
    version_axis = np.array([0., 1., 0. ]) 

    vector = np.array([ -0.98480775,  0.17364818,  0.        ])
    inclination_angle = calculateCupAnlges(inclination_plane, vector, inclination_axis)
    version_angle = calculateCupAnlges(version_plane, vector, version_axis)

    print(inclination_angle)
    print(version_angle)
    