
import plotly.graph_objects as go
# working with directory
from os import listdir
from os.path import isfile, join
# Load data
import pandas as pd
import re

def createFileList(folder, scenario):
    available_files = [files for files in listdir(folder) if isfile(join(folder, files))]
    available_files = [x for x in available_files if '.json' in x] # include only text files
    # identify all output files with required scenario : pelvic/no_pelvic

    file_list = []
    [file_list.append(x) for x in available_files if scenario in x.lower()]
    return file_list

def CalculateRange(file_name, angle_name, out_dataframe):
    # read json file
    data = pd.read_json(file_name, orient='split')
    # extract angle (version or inclination) 
    data = data[angle_name]
    # find maximum and minimum of the angle
    max_data = data.max(axis = 0)
    min_data = data.min(axis = 0)
    average_data = data.mean(axis = 0)
    # read file name only number
    patient_name = re.findall(r'\d{3}', file_name)
    patient_name = str(patient_name).strip('[]')
    patient_name = patient_name.strip('"\'')
    
    # save data to dataframe min and max
    d = {'patient': [patient_name], 'min': [min_data], 'max' : [max_data], 'average' : [average_data]}
    output = pd.DataFrame(d)
    range_df = pd.concat([out_dataframe, output], ignore_index=True)
    return range_df

if (__name__ == '__main__'):

    folder = r'M:\3. Python Projects\test-folder\paper-code\\' # folder path for output of "MAIN.py" 
    output_folder = r'M:\3. Python Projects\test-folder\paper-code\analysis\\' # folder path for output of thi script
    file_list = createFileList(folder, 'trial2angles_results') # each trial analysised sperately for all patients, change trial number in the name if required
    output = pd.DataFrame(columns = ['patient', 'min', 'max', 'average'])
    for i in file_list:
        output = CalculateRange(str(folder + i), 'version', output) # change version to inclination or vice versa
    
    output.to_json(str(output_folder + 'version_wt_ave' + 'trial2_limits_all_patients.json'), orient = 'split') # make sure to rename this appropriatly inclination or version + trial number
    output.to_csv(str(output_folder + 'version_wt_ave' + 'trial2_limits_all_patients.csv'), index = False) # make sure to rename this appropriatly inclination or version + trial number