# Ksenija Vasiljeva 02/12/2021
# Pelvic movement data must be normalised to right hip and stored as shown in "pelvis_example.xlsx"

import CupInitialPostion as cip
import IterationAngles as ita
import CalculateCupOreintation as cco
import numpy as np
from os import listdir 
from os.path import isfile, join
import re
import plotly.graph_objs as go
from plotly.offline import plot
import pandas as pd

def visualiseDynamicCupTrials(figure, input_data, patient, trace_name, color = 'black'):
    
    df_vector_data = pd.read_json(input_data, orient='split')
    hover = [str(i) for i in range(len(df_vector_data.loc[:, 'version'])+1)]
    

    figure.add_trace(go.Scatter( x = df_vector_data.loc[:, 'version'], y = df_vector_data.loc[:, 'inclination'], text = hover,
        name = trace_name, mode = 'markers', marker=dict(
            color = color,
            size=6,
            line=dict(
                color='white',
                width=0.5
            )
    )))


    figure.update_layout(title = 'Dynamic Cup Angles Patient ' + patient, autosize=True, xaxis = dict(
        title = 'Version'),
    yaxis = dict(
        title = 'Inclination'))


if (__name__ == '__main__'):
    #rotate normal vector and version angle
    rotated_vector = cip.rotateCup(np.array([[0., 0., -1.], [1., 0., 0.]]), [0., 1., 0], (-45)) # for 45inclination 7version angles will be -45 and 4.95 respectively 
    rotated_vector = cip.rotateCup(rotated_vector[0], rotated_vector[1], 4.95)
    folder = r"C:\Users\menkva\OneDrive - University of Leeds\0. HIPhip Research Fellow - private\1. Research Fellow iMBE\7. Study 1 Inclination Version Zone\0. LBRCDataRightHip\\"
    results_folder = r"M:\3. Python Projects\test-folder\paper-code\\"
    patient_files = [files for files in listdir(folder) if isfile(join(folder, files))]
    print(patient_files)
    # read pelvic rotations

    for file in patient_files:
    # get patient number 
        
        save_file_name = re.findall(r'\d{3}', str(folder + file))
        save_file_name = str(save_file_name).strip('[]')
        save_file_name = save_file_name.strip('"\'')
        print(save_file_name)
        df_xl = pd.ExcelFile(str(folder + file))
        trial_sheets = df_xl.sheet_names
        figure = go.Figure()

        count = 0 
        colors = ['#636EFA', '#EF553B', '#00CC96']

        for sheet_name in trial_sheets:
            
            results = ita.batchIterationRotate(rotated_vector, str(folder + file), sheet_name, 5, 6, 7, str(results_folder + save_file_name + sheet_name + 'results.json'), 0) 
            
            cco.batchCupAngles(str(results_folder + save_file_name + sheet_name + 'results.json'), str(results_folder + save_file_name + sheet_name + 'angles_results.json'))
            
            visualiseDynamicCupTrials(figure, str(results_folder + save_file_name + sheet_name + 'angles_results.json'), save_file_name, sheet_name, colors[count])
            count+=1

            if count >= 3:
                break

        plot(figure, filename= str(results_folder + save_file_name + 'angles_results.html'), auto_open=False)
        
    print('finished')
    


