# Pelvic movement to Cup Angle conversion


**Converts pelvic movements, recorded in biomechanics gait lab (pre-processed in Visual3D),  to acetabular cup angles *inclination* and *version*** 

All files are in the same folder. Detailed explanation of most files inside the file itself. Below brief decription. 

Libraries to install

​	numpy, os, re, plotly, pandas, math, pyquaternion, statistics, matplotlib, scipy, json, itertool, 		collections.abc, statsmodels, spm1d, 

Abbreviations: 

GCP - gait cycle point, MLCF - medial-lateral contact force, APCF - anterior-posterior contact force, SICF - superior-inferior contact force, TPA - pelvic tilt, OPA - pelvic obliquity, IEPA - internal-external rotation pelvic, FHA - flexion hip angle, ABHA - abduction hip angle, IEHA - internal-external hip angle, **HF - high functioning i.e. fast walking, LF (also CRLF) - low functioning i.e. slow walking**,  

Typical Flow: 

1. Create pelvic movement files based on the examples provided ("pelvis-example.xlsx" and "average-pelvis-example.xlsx"). The code won't read any other format. GCP, TPA, OPA, IEPA columns **must**be present, others are not required for main code execution. 

2. run "MAIN.py" - adjust input and output folders after "if (__name__ == '__main__')"

   *Post-Processing minimum, maximum, average for average gait trial between two groups  fast-walking and slow-walking:*

3.  run "LimitsAnalysis.py"

4. run "LimitsAnalysisAllTrials.py" 

5. run "StatisticalAnalysis_Cardan.ipynb"  

6.  run "Plot_IncVsVers.py" 

   *Post-Processing for every gait cycle point*

   6. run "RecordMeanFiles.py"
   7. run "RecordMeanMotionFiles.py"
   8. run "SPM_Analysis_Cardan.ipynb" 
   9. run "Correlation_Analysis_Cardan.ipynb" 

Raw Data Processing of Gait Data for Fast&Slow comparison

1. "MAIN.py" : batch process all patients in one folder and converts pelvic movement to cup orientations (both inclination and version). Outputs .json file for each patient with angle data
3. Supporting scripts for raw data processing: 
   1. "CupIntialPosition.py"
   2. "IterationAngles.py"
   3. "CalculateCupOrientation.py"

Post-processing

1. "LimitsAnalysis.py" - create a min, max and average for each patient and one trial, save to .json and .csv
2. "LimitsAnalysisAllTrials.py" - combine above to one file and save to .json and .csv
5.  "RecordMeanFiles.py" - mean cup angles of all trials for every gait cycle point - all patients together in one file
5.  "RecordMeanMotionFiles.py" - mean pelvic movement for every gait cycle point in json format - all patients together in one file

Statistical Analysis

​	This will need to be opened as ipython notebook, either in jupyter or kaggle.com

 	1. "SPM_Analysis_Cardan.ipynb" (based on https://spm1d.org/)- includes visualisation for paper
 	2. "SPM_Pelvic_Movement.ipynb" (based on https://spm1d.org/)- includes visualisation for paper
 	3. "StatisticalAnalysis_Cardan.ipynb" 
 	4. "Correlation_Analysis_Cardan.ipynb" - Spearmans rank, between a pelvic movement and a cup angle

Visualisation

1. "Plot_IncVsVers.py" - visualise across whole (mean of trials) gait cycle for each patient and limits (min/max bars) , visualisation for the paper

Others

1. "json2csv.py" - converts json files to csv, for visual inspection. one file at a time
2. "pelvis-example.xlsx" - pelvic movement for each gait trial
2. "average-pelvis-example.xlsx" - average of the above ("pelvis-example.xlsx" )

